/**
 * Forwarding system module
 * Provides a flexible and type-safe way to configure and manage various forwarding strategies
 */

// Export types and configuration
export * from './config/forwarding-types.js';

// Export handlers
export { ForwardingHandler } from './handlers/base-handler.js';
export * from './handlers/http-handler.js';
export * from './handlers/https-passthrough-handler.js';
export * from './handlers/https-terminate-to-http-handler.js';
export * from './handlers/https-terminate-to-https-handler.js';

// Export factory
export * from './factory/forwarding-factory.js';

// Helper functions as a convenience object
import {
  httpOnly,
  tlsTerminateToHttp,
  tlsTerminateToHttps,
  httpsPassthrough
} from './config/forwarding-types.js';

// Export route-based helpers from smart-proxy
export * from '../proxies/smart-proxy/utils/route-helpers.js';

export const helpers = {
  httpOnly,
  tlsTerminateToHttp,
  tlsTerminateToHttps,
  httpsPassthrough
};